@@ -1,3 +1,3 @@
 "convhulln" <-
-function (p, options = " ") 
+function (p, options = "Tv") 
 .Call("convhulln", as.matrix(p), as.character(options))
